Module arrow

Module arrow 

Arrow batch building utilities.

Provides ArrowBatchBuilder for incrementally constructing Arrow RecordBatch values from dynamically-typed ArrowValue rows, and RecordBatchCollector for accumulating completed batches.

Structs

ArrowBatchBuilder
Incremental Arrow RecordBatch builder.
RecordBatchCollector
Accumulator for completed RecordBatch values.

Enums

ArrowValue
A dynamically-typed cell value for one column of an Arrow row.

Functions

schema_from_fields
Create an Arrow schema from a list of fields.