pub struct WriterStats {
pub batches_received: u64,
pub rows_received: u64,
pub batches_sent: u64,
pub rows_sent: u64,
pub errors: u64,
pub batches_failed: u64,
pub rows_failed: u64,
pub batches_spilled: u64,
pub rows_spilled: u64,
pub max_outstanding_batches: u64,
}Expand description
Statistics from the writer’s lifetime.
Fields
batches_received: u64Number of batches accepted by the background writer loop.
rows_received: u64Total number of rows accepted by the background writer loop.
batches_sent: u64Number of batches successfully sent.
rows_sent: u64Total number of rows across all successful batches.
errors: u64Total number of failed send attempts (including retries).
batches_failed: u64Number of batches dropped after all retries were exhausted.
rows_failed: u64Total number of rows dropped after all retries were exhausted.
batches_spilled: u64Number of batches that were persisted to the spill directory after all
retries were exhausted. Always 0 when the spill feature or
ClickHouseConfig::spill_dir is not configured. Spilled batches are
counted in batches_failed/rows_failed as well.
rows_spilled: u64Total number of rows persisted to the spill directory.
max_outstanding_batches: u64Maximum observed outstanding-batch count submitted to the writer.